@@ -1,15 +1,17 @@
+use strict;
 use GD::Graph::bars;
 use GD::Graph::colour;
+use GD::Graph::Data;
 require 'save.pl';
 
 print STDERR "Processing sample 1-1\n";
 
-@data = ( 
+my $data = GD::Graph::Data->new([
     ["1st","2nd","3rd","4th","5th","6th","7th", "8th", "9th"],
     [    1,    2,    5,    6,    3,  1.5,    1,     3,     4],
-);
+]) or die GD::Graph::Data->error;
 
-$my_graph = new GD::Graph::bars();
+my $my_graph = GD::Graph::bars->new();
 
 $my_graph->set( 
 	x_label => 'X Label',
@@ -26,6 +28,6 @@ $my_graph->set(
 ) 
 or warn $my_graph->error;
 
-$my_graph->plot(\@data) or die $my_graph->error;
+$my_graph->plot($data) or die $my_graph->error;
 save_chart($my_graph, 'sample11');
 
