@@ -1,7 +1,7 @@
 use GD::Graph::points;
 require 'save.pl';
 
-print STDERR "Processing sample31\n";
+print STDERR "Processing sample 3-1\n";
 
 @data = ( 
     ["1st","2nd","3rd","4th","5th","6th","7th", "8th", "9th"],
@@ -9,7 +9,7 @@ print STDERR "Processing sample31\n";
     [    1,    2,    5,    6,    3,  1.5,    undef,     3,     4],
 );
 
-$my_graph = new GD::Graph::points(400,300,1);
+$my_graph = new GD::Graph::points();
 
 $my_graph->set( 
 	x_label => 'X Label',
@@ -21,11 +21,7 @@ $my_graph->set(
 	legend_placement => 'RC',
 	long_ticks => 1,
 	marker_size => 6,
-	markers => [ 9, 10, 1, 7, 5 ],
-
-	transparent => 0,
-	aa=>1,
-	alpha=>100,
+	markers => [ 1, 7, 5 ],
 );
 
 $my_graph->set_legend( qw( one two ) );
